function [y1,y2] = CrossCoupler(Input_optical1,Input_optical2,alpha)
%
% Usage: [y1,y2] = CrossCoupler(Input_optical1,Input_optica2,alpha)
%
% Purpose = This module models an optical coupler.
%
% Input Signal(Input_optical1) = Optical Filed Signal at port 1
% Input Signal(Input_optical2) = Optical Field Signal at port 2
%
% Output Signal(y1) = Optical Field Signal at port 3
% Output Signal(y2) = Optical Field Signal at port 4
%
% === Physical Parameter ===
% alpha = coupling coefficient [0,1] 
%       = 0.5 (default)
%
%------------------------------------------------------------
% $ Revision: 1.0 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================================

if nargin<3, 
    alpha=0.5;
end

y1 = sqrt(1-alpha)*Input_optical1+1i*sqrt(alpha)*Input_optical2;
y2 = 1i*sqrt(alpha)*Input_optical1+sqrt(1-alpha)*Input_optical2;
