function EyePlotter2(InSignal,info_bit)
%
% Usage: EyePlotter2(InSignal,info_bit)
%
% Purpose = This module is to generate an eye diagram with the synchronied pulse train.
%
% Input1(InSignal) = Single channel signal (optical/electrical), Size = [1 x DataLength]
% Input2(info_bit) = Bit sequence sent at the transmitter
%
% Output = Eye diagram figure 
%
% Note 1) Time axis covers one bit periods.
% Note 2) When the bit number is relatively small ( < 128), 'Synchronizer' may not work properly. 
%         In that case, this module can NOT display a synchronized one bit period eye diagram properly.
%         By increasing bit numbers, this problem can be solved. 
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%=====================================================================================
global BitRate SampleRate samplesperbit Bits

s_type = isreal(InSignal);

[Syn_out ref_pulse] = Synchronizer(InSignal,info_bit);

t_eye = 1e9*(0:1/SampleRate:(1/BitRate - 1/SampleRate));% 1 bit periods in [ns] unit

  
   for k= 1:Bits

	eye_d(:,k) = Syn_out((k-1)*samplesperbit+1:k*samplesperbit);

   end
   
   
   if s_type == 1; % Electrical signal case
      
   figure
   plot(t_eye,1e3*eye_d)
   grid on
   title('Eye Diagram _ Electrical Signal','FontSize',12)
   xlabel('time [ns]','FontSize',12)
   ylabel('Magnitude [mA or mV]','FontSize',12)
   
   else            % Optical signal case
      
   figure
   plot(t_eye,1e3*(eye_d.*conj(eye_d)),'r') ;% 1e3 for [mW] 
   grid on
   title('Eye Diagram _ Optical Signal','FontSize',12)
   xlabel('time [ns]','FontSize',12)
   ylabel('Power [mW]','FontSize',12)

   
   end
   
