function y = Modulator_Mach_Zehnder(carrier,data,ExtinctionRatio,SymmetryFactor,ChirpSign)
%
% Usage : y = Modulator_Mach_Zehnder(carrier,data,ExtinctionRatio,SymmetryFactor,ChirpSign)
%
% Purpose = This module simulates a Mach-Zehnder modulator.
%
% Input1(carrier) = optical carrier.
% Input2(data) = electrical modulation signal
%
% Output Signal = modulated optical signal
%
% === Physical Parameters === 
% ExtinctionRatio [dB]   [0,inf[   default = 30
% SymmetryFactor  []     [-1 1]    default = -1
% ChirpSign       []      +/-1     default = +1
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==============================================================
if nargin<5,
   ChirpSign = 1;
end
if nargin<4,
  SymmetryFactor = -1;
end
if nargin<3,
  ExtinctionRatio = 30;
end
if nargin<2, 
  help Modulator_Mach_Zehnder; 
  return; 
end

f_ext = 10^(ExtinctionRatio/10);
ext = 1 - 4*atan(1/sqrt(f_ext))/pi;
dPhase = (pi/2)*(0.5-ext*(data-0.5)); 
MZPhase = ChirpSign*((1+SymmetryFactor)/(1-SymmetryFactor))*dPhase;

y = carrier.*sqrt(cos(dPhase).*cos(dPhase)).*exp(1i*MZPhase);
