function OsnrdB = OSNR_MeterArray(Input_optical,BW_sig, BW_noise,MeasurementFilter_Type)
%
% Usage: OsnrdB = OSNR_MeterArray(Input_optical,BW_sig, BW_noise,MeasurementFilter_Type)
%
% Purpose = This module is to calcaulate optical signal-to-noise power
%           ratio of each channels in a WDM system. 
%
%  Input Signal(Input_optical) = Optical Signal
%  Output(OsnrdB) = Optical signal-to-noise ratio in [dB] for each channels
%
% ==== Physical Parameters ===== 
%   BW_sig = Signal Bandwidth [Hz], signal power will be calculated within BW_sig
%          = BitRate (default)
%   BW_noise = Noise Bandwidth [Hz], noise power will be calculated within BW_noise
%            = BitRate (default)
%   MeasurementFilter_Type = 'Gauss','Rectangular'(ideal), 'Bessel'
%                          = 'Gauss' (default)  
%
%   (global)  ChannelSpacing  ChannelNumber BitRate
%
%   Note1) Null-to-Null bandwidth of ideal NRZ signal = 2*BitRate ( BW_sig
%   should be increased when RZ signal is used.)
%   Note2) Noise power will be measured at +/- ChannelSpacing/2 from Signal Center Frequency. In band noise power is estimated by the average of noise powers at the two points.  
%   Note3) BW_noise could be different from BW_sig.
%   Note4) Can be used in a Single Channel (ChannelNumber =1)
%   Note5) 'ChannelSpacing'  'ChannelNumber' should be defined as global variables  
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================================
global ChannelSpacing  ChannelNumber BitRate

if nargin<4,
   MeasurementFilter_Type = 'Gauss';
end
if nargin<3,
 BW_noise = BitRate;
end
if nargin<2,
  BW_sig = BitRate;
end

FirstChannelFrequency = -ChannelSpacing*((ChannelNumber-1)/2);

for k = 1:ChannelNumber 
      OsnrdB(k) = OSNR_Meter(Input_optical,BW_sig, BW_noise,ChannelSpacing/2,FirstChannelFrequency +ChannelSpacing*(k-1),MeasurementFilter_Type);
end
