function y = RaisedCosineElectrical(info_bits,PulseWidth,Amplitude,Bias,...
                                    ExcessBWfactor,CenterPosition,ExcessPulseSlots) 
%
% Usage: y = RaisedCosineElectrical(info_bits,PulseWidth,Amplitude,Bias,...
%                                    ExcessBWfactor,CenterPosition,ExcessPulseSlots)
%
% Purpose = This function generates raised-cosine electrical pulses, modulated by a bit sequence.
%
% Input(info_bits) = bit sequence (Interger)
% Output(y) = Raised-cosine electrical pulse
%
% ===== Physical Parameters ======
% PulseWidth [sec], default = 1/3/BitRate  
% Amplitude  [a.u.], default = 1e-3
% Bias    [a.u.], default = 0
% ExcessBWfactor  [0,1], default = 1
% CenterPosition ; Relative position of the pulse center wrt bit frame  %[-0.5 0.5] default = 0 (center)
% ExcessPulseSlots; Number of extra bit slot to consider neighboring bits, default = 3;
%
% (global variables) BitRate Bits samplesperbit SampleRate 
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==========================================================================================
global BitRate Bits samplesperbit SampleRate 

if nargin<7,
   ExcessPulseSlots = 3;% 
end
if nargin<6,
   CenterPosition = 0;% 
end
if nargin<5,
   ExcessBWfactor = 1;% 
end
if nargin<4,
   Bias = 0;% 
end
if nargin<3,
   Amplitude = 1e-3;% 
end
if nargin<2,
   PulseWidth = 1/3/BitRate;% [W]
end

%--------------------------------------------------------------------------

Tb = 1/BitRate;
t_b = -ExcessPulseSlots*Tb:1/SampleRate:(ExcessPulseSlots*Tb-1/SampleRate);

t_bits = t_b - CenterPosition*Tb;
tau = t_bits/PulseWidth;

RaisedP1 = sin(pi*tau).*cos(ExcessBWfactor*pi*tau) + realmin; % realmin added to avoid dividing by zero.
RaisedP2 = pi*tau.*(1 - (2*ExcessBWfactor*tau).^2) + realmin ;% realmin added to avoid dividing by zero.

RaisedP = Amplitude*RaisedP1./RaisedP2;

RaisedT = info_bits'*RaisedP;

% Now for delayed pulses

   for k=1:Bits

     y1(k,:)=[zeros(1,samplesperbit*(k-1)) RaisedT(k,:) zeros(1,(Bits-k)*samplesperbit)];
       
   end
   
pulses1 = sum(y1);   

r_Excess = ExcessPulseSlots - 0.5; 

y = Bias + pulses1((r_Excess*samplesperbit+1):(length(pulses1)-r_Excess*samplesperbit));

