function y = Rx_PIN(E_optical,Responsivity,ThermalNoiseDen,DarkCurrent,ShotNoiseFactor,FilterOrder,BW3dB)  
%
% Usage : y = Rx_PIN(E_optical,Responsivity,ThermalNoiseDen,DarkCurrent,ShotNoiseFactor,FilterOrder,BW3dB)
%
% Purpose = This module acts as a receiver consisted with a PIN photodiode and a low pass Bessel filter.
%
% Input Signal (E_optical) = Received Optical Signal 
% Output Signal (y) = Electrical Signal 
%
% === Physical Parameters ===
% Responsivity = 1.0 [A/W], [0,2]
% ThermalNoiseDen = 1e-22 [A^2/Hz], Power Spectral Density of Thermal noise 
% DarkCurrent = 0 [A], [0,10e-6]
% ShotNoiseFactor = 1   (1 if shot noise included, 0 if not)
%
% FilterOrder = positive integer
% BW3dB [Hz] = 3dB Bandwidth of Electrical Low Pass Filter (positive frequency)
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%====================================================================================
global BitRate

if nargin<7,
   BW3dB = 0.7*BitRate;
end
if nargin<6,
   FilterOrder = 3;
end
if nargin<5,
   ShotNoiseFactor = 1;
end
if nargin<4,
  DarkCurrent = 0 ;
end
if nargin<3,
  ThermalNoiseDen = 1e-22 ;% [A^2/Hz]
end
if nargin<2, 
  Responsivity = 1.0; %[A/W]
end
%===============================================================================

i_pin = PhotoDiode_PIN(E_optical,Responsivity,ThermalNoiseDen,DarkCurrent,ShotNoiseFactor);

%======== Filtering by Bessel Low-pass filter ==============
y = E_FilterLPBessel(i_pin,FilterOrder,BW3dB); 
