function [y,info_bits] = Tx_PulseSechantOptical(PeakPower,FWHM,ExcessPulseSlots,CenterPosition,...
                         PreSpaces,PostSpaces)
%
% Usage: [y,info_bits] = Tx_PulseSechantOptical(PeakPower,FWHM,ExcessPulseSlots,CenterPosition,...
%                         PreSpaces,PostSpaces)
%
% Purpose = This function simulates a transmitter generating sechant optical pulses,
%           modulated by a bit sequence.
%
% Tx_PulseSechantOptical = PRBS generator + PulseSechantOptical
%
% Input = Not required.
% Output1(y) = Sechant optical pulse with info_bits for BER calculation at the receiver.
% Output2(info_bits) = info_bits for BER calculation at the receiver.
%
% ===== Physical Parameters ======
% PeakPower ; [W] default = 1e-3;
% FWHM, Full width at half maximum power [sec], default = 1/3/BitRate;
% ExcessPulseSlots; Number of extra bit slots for each side to consider overlapping 
%                         with neighboring bits, default = 3;
% CenterPosition ; Relative position of the pulse peak wrt bit frame  %[-0.5 0.5], default = 0 (center)
%     
% PreSpaces = 2 (default); % number of leading zero bits, infobits_PRBS
% PostSpaces = 2 (default); % number of trailing zero bits, infobits_PRBS
%
% Note) y (Single Pulse) = sqrt(PeakPower)./cosh(2*t_bits/FWHM*acosh(sqrt(2))); 
% 
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==========================================================================================
global BitRate

if nargin <6
    PostSpaces = 2;   
end    
if nargin<5,
    PreSpaces = 2;
end
if nargin<4,
   CenterPosition = 0;% 
end
if nargin<3,
   ExcessPulseSlots = 3;% 
end
if nargin<2,
   FWHM = 1/3/BitRate;% 
end
if nargin==0,
   PeakPower = 1e-3;% [W]
end

%--------------------------------------------------------------------------

info_bits = infobits_PRBS(PreSpaces,PostSpaces); 
y = PulseSechantOptical(info_bits,PeakPower,FWHM,ExcessPulseSlots,CenterPosition);

