function y = WDM_DeMux_Gaussian(Optical_input,BW_3dB,IL)  
%
% Usage: y = WDM_DeMux_Gaussian(Optical_input,BW_3dB,IL)
%
% Purpose = This module represents a DeMux with Gaussian shaped optical filters.
%
% Input Signal(Optical_input) = (Composite) Optical Signal (size = [1 x DataLength])
% Output Signal(y) = Demuxed (filtered & sorted) Optical Signal (size = [ChannelNumber x DataLength])
%
% ==== Physical Parameters ===== 
%   BW_3dB = 3dB bandwidth [Hz]
%          = 4*BitRate (default)
%   IL  = insertion loss [dB]
%       = 3 (default) 
%
% Note1) Output size = FilterNumber by DataLength
% Note2) All the filter characteristicas (shape, bandwidth, and IL) are assumed equal.
% Note3) Filter spacing is uniform.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%=================================================================================================
global ChannelNumber ChannelSpacing BitRate

if nargin<3,
   IL = 3;% [dB]
end

if nargin<2,
 BW_3dB = 4*BitRate;
end

AfterIL = Attenuator(Optical_input,IL);

FilterNumber = ChannelNumber;
FilterSpacing = ChannelSpacing;


if FilterNumber == 1
   
    y = OpticalFilter_Gaussian(AfterIL,0,BW_3dB);
        
else
   
    for k = 1:FilterNumber
              
          FilterCenter(k) = FilterSpacing*(k - (FilterNumber+1)/2);
          y(k,:) = OpticalFilter_Gaussian(AfterIL,FilterCenter(k),BW_3dB);%                
       
     end  
     
 end    
    
